@@ -4,8 +4,10 @@ from typing import Any, Dict, Optional
 from pydantic import UUID4
 
 import dataquality
+from dataquality.analytics import Analytics
 from dataquality.clients.api import ApiClient
 from dataquality.core._config import config
+from dataquality.core.report import build_run_report
 from dataquality.schemas import RequestType, Route
 from dataquality.schemas.job import JobName
 from dataquality.schemas.task_type import TaskType
@@ -15,6 +17,7 @@ from dataquality.utils.thread_pool import ThreadPoolManager
 from dataquality.utils.version import _version_check
 
 api_client = ApiClient()
+a = Analytics(ApiClient, config)  # type: ignore
 
 
 @check_noop
@@ -30,6 +33,7 @@ def finish(
         run to be processed by the Galileo server. If false, you can manually wait
         for the run by calling `dq.wait_for_run()` Default True
     """
+    a.log_function("dq/finish")
     ThreadPoolManager.wait_for_threads()
     assert config.current_project_id, "You must have an active project to call finish"
     assert config.current_run_id, "You must have an active run to call finish"
@@ -64,8 +68,22 @@ def finish(
         f"Job {res['job_name']} successfully submitted. Results will be available "
         f"soon at {res['link']}"
     )
-    if wait:
+    if data_logger.logger_config.conditions:
+        print(
+            "Waiting for run to process before building run report... "
+            "Don't close laptop or terminate shell."
+        )
         wait_for_run()
+        build_run_report(
+            data_logger.logger_config.conditions,
+            data_logger.logger_config.report_emails,
+            project_id=config.current_project_id,
+            run_id=config.current_run_id,
+            link=res["link"],
+        )
+    elif wait:
+        wait_for_run()
+
     # Reset the environment
     data_logger._cleanup()
     return res
