@@ -8,7 +8,7 @@ from pydantic.types import UUID4
 
 import dataquality
 from dataquality.clients.api import ApiClient
-from dataquality.core._config import config
+from dataquality.core._config import _check_dq_version, config
 from dataquality.core.auth import login
 from dataquality.exceptions import GalileoException
 from dataquality.loggers import BaseGalileoLogger
@@ -18,6 +18,7 @@ from dataquality.utils.helpers import check_noop
 from dataquality.utils.name import random_name
 
 api_client = ApiClient()
+BAD_CHARS_REGEX = r"[^\w -]+"
 
 
 class _Init:
@@ -73,7 +74,7 @@ class _Init:
         """Validates project/run name ensuring only letters, numbers, space, - and _"""
         if not name:
             return
-        badchars = re.findall(r"[^\w -]+", name)
+        badchars = re.findall(BAD_CHARS_REGEX, name)
         if badchars:
             raise GalileoException(
                 "Only letters, numbers, whitespace, - and _ are allowed in a project "
@@ -95,6 +96,10 @@ def init(
     Initialize a new run and new project, initialize a new run in an existing project,
     or reinitialize an existing run in an existing project.
 
+    Before creating the project, check:
+    - The user is valid, login if not
+    - The DQ client version is compatible with API version
+
     Optionally provide project and run names to create a new project/run or restart
     existing ones.
 
@@ -113,6 +118,7 @@ def init(
     """
     if not api_client.valid_current_user():
         login()
+    _check_dq_version()
     _init = _Init()
     BaseGalileoLogger.validate_task(task_type)
     task_type = TaskType[task_type]
@@ -201,7 +207,7 @@ def init(
         # The user provided a run name and no project name. No good
         warnings.warn(
             "⚠️ You must specify a project name to initialize or create a new Galileo "
-            "run. Add a project name, or simply run dataquality.init()."
+            "run. Add a project name, or simply run dq.init()."
         )
         return
     config.update_file_config()
