@@ -15,6 +15,7 @@ from dataquality.loggers.logger_config.base_logger_config import (
 )
 from dataquality.schemas.split import Split, conform_split
 from dataquality.schemas.task_type import TaskType
+from dataquality.utils.cloud import is_galileo_cloud
 from dataquality.utils.dq_logger import upload_dq_log_file
 from dataquality.utils.tf import TF_AVAILABLE, is_tf_2
 
@@ -86,6 +87,19 @@ class BaseGalileoLogger:
 
     def __init__(self) -> None:
         self.split: Optional[str] = None
+        self.inference_name: Optional[str] = None
+
+    def write_output_dir(self) -> str:
+        return (
+            f"{BaseGalileoLogger.LOG_FILE_DIR}/{config.current_project_id}/"
+            f"{config.current_run_id}"
+        )
+
+    def split_name(self) -> str:
+        split = self.split
+        if split == Split.inference:
+            split = f"{split}_{self.inference_name}"
+        return str(split)
 
     @staticmethod
     def get_valid_attributes() -> List[str]:
@@ -185,6 +199,11 @@ class BaseGalileoLogger:
         if TORCH_AVAILABLE:
             if isinstance(v, Tensor):
                 v = int(v.numpy())  # Torch tensors cannot hold strings
+        if isinstance(v, np.ndarray):
+            if np.issubdtype(v, np.integer):
+                v = int(v)
+            else:
+                v = str(int(v))
         if not isinstance(v, (int, str)):
             raise GalileoException(
                 f"Logged data should be of type int, string, pytorch tensor, "
@@ -203,7 +222,7 @@ class BaseGalileoLogger:
     @classmethod
     def _cleanup(cls) -> None:
         """
-        Cleans up the current run data locally
+        Cleans up the current run data and metadata locally
         """
         assert config.current_project_id
         assert config.current_run_id
@@ -217,9 +236,9 @@ class BaseGalileoLogger:
                 os.remove(path)
             else:
                 shutil.rmtree(path)
+        cls.logger_config.reset()
 
-    @classmethod
-    def upload(cls) -> None:
+    def upload(self) -> None:
         ...
 
     @classmethod
@@ -244,7 +263,14 @@ class BaseGalileoLogger:
 
     @classmethod
     def validate_split(cls, split: Union[str, Split]) -> str:
-        return conform_split(split).value
+        split = conform_split(split).value
+        if is_galileo_cloud() and split == Split.inference:
+            raise GalileoException(
+                "You cannot log inference data from a Galileo Cloud account, only "
+                "enterprise accounts can access this feature. Please email us at "
+                "team@rungalileo.io for more information."
+            )
+        return split
 
     @classmethod
     def check_for_logging_failures(cls) -> None:
