@@ -422,7 +422,6 @@ ADJECTIVES = [
     "future",
     "fuzzy",
     "gastric",
-    "gay",
     "general",
     "generous",
     "genetic",
@@ -459,7 +458,6 @@ ADJECTIVES = [
     "handicapped",
     "handsome",
     "happy",
-    "hard",
     "harsh",
     "head",
     "healthy",
@@ -555,7 +553,6 @@ ADJECTIVES = [
     "jolly",
     "joyous",
     "judicial",
-    "juicy",
     "junior",
     "just",
     "keen",
@@ -619,7 +616,6 @@ ADJECTIVES = [
     "marked",
     "married",
     "marvellous",
-    "marxist",
     "mass",
     "massive",
     "mathematical",
@@ -650,7 +646,6 @@ ADJECTIVES = [
     "missing",
     "misty",
     "mixed",
-    "moaning",
     "mobile",
     "moderate",
     "modern",
@@ -667,13 +662,10 @@ ADJECTIVES = [
     "mute",
     "mutual",
     "mysterious",
-    "naked",
     "narrow",
-    "nasty",
     "national",
     "native",
     "natural",
-    "naughty",
     "naval",
     "near",
     "nearby",
@@ -695,7 +687,6 @@ ADJECTIVES = [
     "novel",
     "nuclear",
     "numerous",
-    "nursing",
     "nutritious",
     "nutty",
     "obedient",
@@ -716,7 +707,6 @@ ADJECTIVES = [
     "operational",
     "opposite",
     "optimistic",
-    "oral",
     "ordinary",
     "organic",
     "organisational",
@@ -750,7 +740,6 @@ ADJECTIVES = [
     "permanent",
     "persistent",
     "personal",
-    "petite",
     "philosophical",
     "physical",
     "plain",
@@ -802,8 +791,6 @@ ADJECTIVES = [
     "protestant",
     "proud",
     "provincial",
-    "psychiatric",
-    "psychological",
     "public",
     "puny",
     "pure",
@@ -818,7 +805,6 @@ ADJECTIVES = [
     "quiet",
     "quintessential",
     "quixotic",
-    "racial",
     "radical",
     "rainy",
     "random",
@@ -826,8 +812,6 @@ ADJECTIVES = [
     "rare",
     "raspy",
     "rational",
-    "ratty",
-    "raw",
     "ready",
     "real",
     "realistic",
@@ -880,7 +864,6 @@ ADJECTIVES = [
     "rough",
     "round",
     "royal",
-    "rubber",
     "rude",
     "ruling",
     "running",
@@ -912,7 +895,6 @@ ADJECTIVES = [
     "separate",
     "serious",
     "severe",
-    "sexual",
     "shaggy",
     "shaky",
     "shallow",
@@ -947,7 +929,6 @@ ADJECTIVES = [
     "smoggy",
     "smooth",
     "social",
-    "socialist",
     "soft",
     "solar",
     "sole",
@@ -984,7 +965,6 @@ ADJECTIVES = [
     "steady",
     "steep",
     "sticky",
-    "stiff",
     "still",
     "stingy",
     "stormy",
@@ -998,7 +978,6 @@ ADJECTIVES = [
     "strong",
     "structural",
     "stuck",
-    "stupid",
     "subjective",
     "subsequent",
     "substantial",
@@ -1049,14 +1028,11 @@ ADJECTIVES = [
     "thoughtful",
     "thoughtless",
     "thundering",
-    "tight",
-    "tiny",
     "tired",
     "top",
     "tory",
     "total",
     "tough",
-    "toxic",
     "traditional",
     "tragic",
     "tremendous",
@@ -1064,8 +1040,6 @@ ADJECTIVES = [
     "tropical",
     "troubled",
     "typical",
-    "ugliest",
-    "ugly",
     "ultimate",
     "unable",
     "unacceptable",
@@ -1090,8 +1064,6 @@ ADJECTIVES = [
     "unknown",
     "unlikely",
     "unnecessary",
-    "unpleasant",
-    "unsightly",
     "unusual",
     "unwilling",
     "upper",
@@ -1101,7 +1073,6 @@ ADJECTIVES = [
     "urgent",
     "used",
     "useful",
-    "useless",
     "usual",
     "vague",
     "valid",
@@ -1123,14 +1094,11 @@ ADJECTIVES = [
     "visual",
     "vital",
     "vitreous",
-    "vivacious",
     "vivid",
     "vocal",
     "vocational",
     "voiceless",
-    "voluminous",
     "voluntary",
-    "vulnerable",
     "wandering",
     "warm",
     "wasteful",
@@ -1191,18 +1159,12 @@ ADJECTIVES = [
     "youngest",
     "youthful",
     "ytterbic",
-    "yucky",
-    "yummy",
     "zany",
     "zealous",
     "zeroth",
     "zestful",
     "zesty",
     "zippy",
-    "zonal",
-    "zoophagous",
-    "zygomorphic",
-    "zygotic",
 ]
 
 ANIMALS = [
@@ -1336,7 +1298,6 @@ ANIMALS = [
     "goldfish",
     "goose",
     "gopher",
-    "gorilla",
     "grasshopper",
     "grouse",
     "guan",
