@@ -1,7 +1,6 @@
 import os
 import shutil
 from typing import Any, Callable, Dict, Generator, List
-from unittest.mock import MagicMock
 from uuid import UUID
 
 import pytest
@@ -10,11 +9,12 @@ import spacy
 from vaex.dataframe import DataFrame
 
 import dataquality
-from dataquality import config
+from dataquality import AggregateFunction, Condition, Operator, config
 from dataquality.clients import objectstore
 from dataquality.loggers import BaseGalileoLogger
 from dataquality.schemas.task_type import TaskType
 from dataquality.utils.dq_logger import DQ_LOG_FILE_HOME
+from tests.test_utils.mock_request import MockResponse
 
 DEFAULT_API_URL = "http://localhost:8088"
 DEFAULT_PROJECT_ID = UUID("399057bc-b276-4027-a5cf-48893ac45388")
@@ -36,11 +36,12 @@ def disable_network_calls(request, monkeypatch):
     if "noautofixt" in request.keywords:
         return
 
-    def stunted_get(url: str) -> MagicMock:
+    def stunted_get(url: str) -> MockResponse:
         """Unless it's a mocked call to healthcheck, disable network access"""
-        if url.endswith("healthcheck"):
-            mock = MagicMock(ok=True)
-            return mock
+        if "healthcheck" in url:
+            return MockResponse(
+                json_data={"minimum_dq_version": "0.0.0"}, status_code=200
+            )
         raise RuntimeError("Network access not allowed during testing!")
 
     monkeypatch.setattr(requests, "get", lambda url, *args, **kwargs: stunted_get(url))
@@ -51,7 +52,6 @@ def cleanup_after_use() -> Generator:
     for task_type in list(TaskType):
         dataquality.get_model_logger(task_type).logger_config.reset()
     try:
-        dataquality.get_model_logger().logger_config.reset()
         if os.path.isdir(BaseGalileoLogger.LOG_FILE_DIR):
             shutil.rmtree(BaseGalileoLogger.LOG_FILE_DIR)
         if not os.path.isdir(TEST_PATH):
@@ -62,9 +62,12 @@ def cleanup_after_use() -> Generator:
             os.makedirs(DQ_LOG_FILE_LOCATION)
         yield
     finally:
-        shutil.rmtree(BaseGalileoLogger.LOG_FILE_DIR)
-        shutil.rmtree(DQ_LOG_FILE_LOCATION)
-        dataquality.get_model_logger().logger_config.reset()
+        if os.path.exists(BaseGalileoLogger.LOG_FILE_DIR):
+            shutil.rmtree(BaseGalileoLogger.LOG_FILE_DIR)
+        if os.path.exists(DQ_LOG_FILE_LOCATION):
+            shutil.rmtree(DQ_LOG_FILE_LOCATION)
+        for task_type in list(TaskType):
+            dataquality.get_model_logger(task_type).logger_config.reset()
 
 
 @pytest.fixture()
@@ -122,6 +125,16 @@ def input_data() -> Callable:
     return curry
 
 
+@pytest.fixture()
+def condition() -> Condition:
+    return Condition(
+        agg=AggregateFunction.avg,
+        metric="confidence",
+        operator=Operator.lt,
+        threshold=0.3,
+    )
+
+
 def patch_object_upload(self: Any, df: DataFrame, object_name: str) -> None:
     """
     A patch for the object_store.create_project_run_object_from_df so we don't have to
